==> jc-1.4.0.tar.gz: soot/util/BitSetIterator.h <==
// public class soot.util.BitSetIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6f52aa0a4cfa0a35 soot_util_BitSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_BitSetIterator_H_
#define _JC_soot_util_BitSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_BitSetIterator$sub_refs	_jc_soot_util_BitSetIterator$sub_refs;
typedef struct _jc_soot_util_BitSetIterator$sub_nonrefs	_jc_soot_util_BitSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_BitSetIterator$refs	_jc_soot_util_BitSetIterator$refs;
typedef struct _jc_soot_util_BitSetIterator$nonrefs	_jc_soot_util_BitSetIterator$nonrefs;
typedef struct _jc_soot_util_BitSetIterator$object	_jc_soot_util_BitSetIterator$object;

typedef struct _jc_soot_util_BitSetIterator$fields_struct	_jc_soot_util_BitSetIterator$fields_struct;
typedef const struct _jc_soot_util_BitSetIterator$vmethods	_jc_soot_util_BitSetIterator$vmethods;
typedef const struct _jc_soot_util_BitSetIterator$vtable	_jc_soot_util_BitSetIterator$vtable;
typedef const struct _jc_soot_util_BitSetIterator$vtype	_jc_soot_util_BitSetIterator$vtype;

// Class fields structure
struct _jc_soot_util_BitSetIterator$fields_struct {
	_jc_int_array	*lookup;
};
extern _jc_soot_util_BitSetIterator$fields_struct _jc_soot_util_BitSetIterator$class_fields;

// Constructors
extern void _jc_soot_util_BitSetIterator$method$_init$ad80da77f7da019e(_jc_env *, struct _jc_soot_util_BitSetIterator$object *, struct _jc_long_array *);

// Virtual methods
extern jboolean _jc_soot_util_BitSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_BitSetIterator$object *);
extern jint _jc_soot_util_BitSetIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_soot_util_BitSetIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_BitSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_BitSetIterator$method_info$next$0a35667a0e69bb19;

// Static methods
extern void _jc_soot_util_BitSetIterator$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_util_BitSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_BitSetIterator$object *);
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_soot_util_BitSetIterator$object *);
};

// Vtable
struct _jc_soot_util_BitSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_BitSetIterator$vmethods	soot_util_BitSetIterator;
};

// Vtype
struct _jc_soot_util_BitSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_BitSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_BitSetIterator$sub_refs {
	_jc_long_array	*bits;
};

// Reference instance fields (object)
struct _jc_soot_util_BitSetIterator$refs {
    _jc_soot_util_BitSetIterator$sub_refs	soot_util_BitSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_BitSetIterator$sub_nonrefs {
	jint	index;
	jlong	save;
};

// Non-reference instance fields (object)
struct _jc_soot_util_BitSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_BitSetIterator$sub_nonrefs	soot_util_BitSetIterator;
};

// Object instance structure
struct _jc_soot_util_BitSetIterator$object {
	_jc_soot_util_BitSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_BitSetIterator$vtype	*vtype;
	_jc_soot_util_BitSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_BitSetIterator$vtype _jc_soot_util_BitSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_BitSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_BitSetIterator$class_object;

#endif	/* _JC_soot_util_BitSetIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/BitSetIterator.h <==
// public class soot.util.BitSetIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6f52aa0a4cfa0a35 soot_util_BitSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_BitSetIterator_H_
#define _JC_soot_util_BitSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_BitSetIterator$sub_refs	_jc_soot_util_BitSetIterator$sub_refs;
typedef struct _jc_soot_util_BitSetIterator$sub_nonrefs	_jc_soot_util_BitSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_BitSetIterator$refs	_jc_soot_util_BitSetIterator$refs;
typedef struct _jc_soot_util_BitSetIterator$nonrefs	_jc_soot_util_BitSetIterator$nonrefs;
typedef struct _jc_soot_util_BitSetIterator$object	_jc_soot_util_BitSetIterator$object;

typedef struct _jc_soot_util_BitSetIterator$fields_struct	_jc_soot_util_BitSetIterator$fields_struct;
typedef const struct _jc_soot_util_BitSetIterator$vmethods	_jc_soot_util_BitSetIterator$vmethods;
typedef const struct _jc_soot_util_BitSetIterator$vtable	_jc_soot_util_BitSetIterator$vtable;
typedef const struct _jc_soot_util_BitSetIterator$vtype	_jc_soot_util_BitSetIterator$vtype;

// Class fields structure
struct _jc_soot_util_BitSetIterator$fields_struct {
	_jc_int_array	*lookup;
};
extern _jc_soot_util_BitSetIterator$fields_struct _jc_soot_util_BitSetIterator$class_fields;

// Constructors
extern void _jc_soot_util_BitSetIterator$method$_init$ad80da77f7da019e(_jc_env *, struct _jc_soot_util_BitSetIterator$object *, struct _jc_long_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_BitSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_BitSetIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_util_BitSetIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_soot_util_BitSetIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_BitSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_BitSetIterator$method_info$next$0a35667a0e69bb19;

// Static methods
extern void _jc_soot_util_BitSetIterator$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_BitSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_BitSetIterator$object *) _JC_JCNI_ATTR;
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_soot_util_BitSetIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_BitSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_BitSetIterator$vmethods	soot_util_BitSetIterator;
};

// Vtype
struct _jc_soot_util_BitSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_BitSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_BitSetIterator$sub_refs {
	_jc_long_array	*bits;
};

// Reference instance fields (object)
struct _jc_soot_util_BitSetIterator$refs {
    _jc_soot_util_BitSetIterator$sub_refs	soot_util_BitSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_BitSetIterator$sub_nonrefs {
	jint	index;
	jlong	save;
};

// Non-reference instance fields (object)
struct _jc_soot_util_BitSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_BitSetIterator$sub_nonrefs	soot_util_BitSetIterator;
};

// Object instance structure
struct _jc_soot_util_BitSetIterator$object {
	_jc_soot_util_BitSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_BitSetIterator$vtype	*vtype;
	_jc_soot_util_BitSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_BitSetIterator$vtype _jc_soot_util_BitSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_BitSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_BitSetIterator$class_object;

#endif	/* _JC_soot_util_BitSetIterator_H_ */
